betty.gui package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui package

## Submodules

- betty.gui.app module
  - `ApplicationConfiguration`
    - `ApplicationConfiguration.__init__()`
    - `ApplicationConfiguration.window_height`
    - `ApplicationConfiguration.window_title`
    - `ApplicationConfiguration.window_width`
  - `BettyPrimaryWindow`
    - `BettyPrimaryWindow.__init__()`
    - `BettyPrimaryWindow.clear_caches()`
    - `BettyPrimaryWindow.new_project()`
    - `BettyPrimaryWindow.open_application_configuration()`
    - `BettyPrimaryWindow.open_project()`
    - `BettyPrimaryWindow.report_bug()`
    - `BettyPrimaryWindow.request_feature()`
    - `BettyPrimaryWindow.window_title`
  - `WelcomeWindow`
    - `WelcomeWindow.__init__()`
    - `WelcomeWindow.window_height`
    - `WelcomeWindow.window_width`
- betty.gui.error module
  - `Error`
    - `Error.__init__()`
    - `Error.closeEvent()`
    - `Error.window_height`
    - `Error.window_title`
    - `Error.window_width`
  - `ExceptionCatcher`
    - `ExceptionCatcher.__init__()`
  - `ExceptionError`
    - `ExceptionError.__init__()`
- betty.gui.locale module
  - `LocalizedObject`
    - `LocalizedObject.__init__()`
    - `LocalizedObject.showEvent()`
  - `TranslationsLocaleCollector`
    - `TranslationsLocaleCollector.__init__()`
    - `TranslationsLocaleCollector.locale`
    - `TranslationsLocaleCollector.rows`
- betty.gui.logging module
  - `LogRecord`
    - `LogRecord.__init__()`
  - `LogRecordViewer`
    - `LogRecordViewer.__init__()`
    - `LogRecordViewer.log()`
  - `LogRecordViewerHandler`
    - `LogRecordViewerHandler.__init__()`
    - `LogRecordViewerHandler.emit()`
    - `LogRecordViewerHandler.log`
- betty.gui.model module
  - `EntityReferenceCollector`
    - `EntityReferenceCollector.__init__()`
  - `EntityReferenceSequenceCollector`
    - `EntityReferenceSequenceCollector.__init__()`
- betty.gui.project module
  - `AddLocaleWindow`
    - `AddLocaleWindow.__init__()`
    - `AddLocaleWindow.window_height`
    - `AddLocaleWindow.window_title`
    - `AddLocaleWindow.window_width`
  - `ExtensionPane`
    - `ExtensionPane.__init__()`
  - `GeneralPane`
    - `GeneralPane.__init__()`
  - `GenerateHtmlListForm`
    - `GenerateHtmlListForm.__init__()`
  - `GenerateWindow`
    - `GenerateWindow.__init__()`
    - `GenerateWindow.closeEvent()`
    - `GenerateWindow.window_height`
    - `GenerateWindow.window_title`
    - `GenerateWindow.window_width`
  - `LocalesConfigurationWidget`
    - `LocalesConfigurationWidget.__init__()`
  - `LocalizationPane`
    - `LocalizationPane.__init__()`
  - `ProjectWindow`
    - `ProjectWindow.__init__()`
    - `ProjectWindow.close()`
    - `ProjectWindow.generate()`
    - `ProjectWindow.save_project_as()`
    - `ProjectWindow.serve()`
    - `ProjectWindow.show()`
    - `ProjectWindow.window_title`
- betty.gui.serve module
  - `ServeDemoWindow`
    - `ServeDemoWindow.window_title`
  - `ServeDocsWindow`
    - `ServeDocsWindow.window_title`
  - `ServeProjectWindow`
    - `ServeProjectWindow.window_title`
- betty.gui.text module
  - `Caption`
    - `Caption.__init__()`
  - `Code`
    - `Code.__init__()`
    - `Code.setText()`
  - `Text`
    - `Text.__init__()`
- betty.gui.window module
  - `BettyMainWindow`
    - `BettyMainWindow.__init__()`
    - `BettyMainWindow.close()`
    - `BettyMainWindow.window_height`
    - `BettyMainWindow.window_title`
    - `BettyMainWindow.window_width`

## Module contents

Provide the Graphical User Interface (GUI) for Betty Desktop.

class betty.gui.BettyApplication

  Bases: `QApplication`

  A Betty Qt application.

  Parameters:

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  __init__(*args: Any, **kwargs: Any)
    Parameters:

      - args (`typing.Any`)

      - kwargs (`typing.Any`)

  property app: App

    Get this Qt application’s Betty application.

  classmethod instance() → Self
    Return type:

      `typing.Self`

  with_app(app: betty.app.App) → collections.abc.AsyncIterator[Self]

    Temporarily set assign a Betty application to this Qt application.

    Parameters:

      app (`betty.app.App`)

    Return type:

      `collections.abc.AsyncIterator`[`typing.Self`]

class betty.gui.GuiBuilder

  Bases: `object`

  Allow extensions to provide their own Graphical User Interface component.

  gui_build() → PyQt6.QtWidgets.QWidget

    Build this extension’s Graphical User Interface component.

    Return type:

      `PyQt6.QtWidgets.QWidget`

betty.gui.get_configuration_file_filter() → betty.locale.Str

  Get the Qt file filter for project configuration files.

  Return type:

    `betty.locale.Str`

betty.gui.mark_invalid(widget: PyQt6.QtWidgets.QWidget, reason: str) → None

  Mark a widget as currently containing invalid input.

  Parameters:

    - widget (`PyQt6.QtWidgets.QWidget`)

    - reason (`str`)

  Return type:

    `None`

betty.gui.mark_valid(widget: PyQt6.QtWidgets.QWidget) → None

  Mark a widget as currently containing valid input.

  Parameters:

    widget (`PyQt6.QtWidgets.QWidget`)

  Return type:

    `None`